FormModel<TModel, TModelOutput> class abstract

Constructors

FormModel({required FormGroup form, String? path, FormModel? formModel})

Properties

currentForm FormGroup
no setter
form FormGroup
final
hasChanged bool
no setter
hashCode int
The hash code for this object.
no setterinherited
initial Map<String, Object?>?
final
model → TModelOutput
no setter
path String?
final
rawModel → TModel
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

equalsTo(TModel other) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset({TModel? value, bool updateParent = true, bool emitEvent = true}) → dynamic
submit({required void onValid(TModelOutput model), void onNotValid()?}) → void
toggleDisabled({bool updateParent = true, bool emitEvent = true}) → void
toString() String
A string representation of this object.
inherited
updateInitial(Map<String, Object?>? value, String? path) → void
updateValue(TModel? value, {bool updateParent = true, bool emitEvent = true}) → void
upsertValue(TModel? value, {bool updateParent = true, bool emitEvent = true}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited