RegExpPatternEvaluator class

Evaluates a pattern using a RegExp.

Implemented types

Constructors

RegExpPatternEvaluator(RegExp regExp)
Constructs an instance of the class. The argument regExp must not be null.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → String
Returns the string representation of the pattern
no setteroverride
regExp → RegExp
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasMatch(String input) → bool
Evaluates if the the patter has a match with the input
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited